@@ -22,23 +22,25 @@ import abc
 
 
 class RangeError(Exception, metaclass=abc.ABCMeta):
-    """ Generic Range error. """
+    """Generic Range error."""
 
 
 class RangeValueError(RangeError):
-    """ Raised when a parameter has an unacceptable value.
+    """
+    Raised when a parameter has an unacceptable value.
 
-        May also be raised when the parameter has an unacceptable type.
+    May also be raised when the parameter has an unacceptable type.
     """
 
     _FMT_STR = "value '%s' for parameter %s is unacceptable"
 
     def __init__(self, value, param, msg=None):
-        """ Initializer.
+        """
+        Initializer.
 
-            :param object value: the value
-            :param str param: the parameter
-            :param str msg: an explanatory message
+        :param object value: the value
+        :param str param: the parameter
+        :param str msg: an explanatory message
         """
         # pylint: disable=super-init-not-called
         self.value = value
@@ -53,23 +55,24 @@ class RangeValueError(RangeError):
 
 
 class RangeUnsupportedOpError(RangeError, metaclass=abc.ABCMeta):
-    """ Error when executing unsupported operation on Range. """
+    """Error when executing unsupported operation on Range."""
 
 
 class RangeNonsensicalOpError(RangeUnsupportedOpError, metaclass=abc.ABCMeta):
-    """ Error when requesting an operation that doesn't make sense. """
+    """Error when requesting an operation that doesn't make sense."""
 
 
 class RangeNonsensicalBinOpValueError(RangeNonsensicalOpError):
-    """ Error when requesting a binary operation with a nonsense value. """
+    """Error when requesting a binary operation with a nonsense value."""
 
     _FMT_STR = "nonsensical value for for %s: '%s'"
 
     def __init__(self, operator, other):
-        """ Initializer.
+        """
+        Initializer.
 
-            :param str operator: the operator
-            :param object other: the other argument
+        :param str operator: the operator
+        :param object other: the other argument
         """
         # pylint: disable=super-init-not-called
         self._operator = operator
@@ -80,15 +83,16 @@ class RangeNonsensicalBinOpValueError(RangeNonsensicalOpError):
 
 
 class RangeNonsensicalBinOpError(RangeNonsensicalOpError):
-    """ Error when requesting a binary operation that doesn't make sense. """
+    """Error when requesting a binary operation that doesn't make sense."""
 
     _FMT_STR = "nonsensical operand types for %s: 'Range' and '%s'"
 
     def __init__(self, operator, other):
-        """ Initializer.
+        """
+        Initializer.
 
-            :param str operator: the operator
-            :param object other: the other argument
+        :param str operator: the operator
+        :param object other: the other argument
         """
         # pylint: disable=super-init-not-called
         self._operator = operator
@@ -99,20 +103,21 @@ class RangeNonsensicalBinOpError(RangeNonsensicalOpError):
 
 
 class RangeUnrepresentableResultError(RangeUnsupportedOpError, metaclass=abc.ABCMeta):
-    """ Error when requesting an operation that yields units that cannot
-        be represented with Range, e.g., when multiplying a Range by a Range.
+    """
+    Error when requesting an operation that yields units that cannot
+    be represented with Range, e.g., when multiplying a Range by a Range.
     """
 
 
 class RangePowerResultError(RangeUnrepresentableResultError):
-    """ Error when requesting an operation that would yield a byte power. """
+    """Error when requesting an operation that would yield a byte power."""
 
     def __str__(self):
         return "requested operation result requires non-unit power of bytes"
 
 
 class RangeFractionalResultError(RangeUnrepresentableResultError):
-    """ Error when Range construction is strict. """
+    """Error when Range construction is strict."""
 
     def __str__(self):
         return "requested operation result has a fractional quantity of bytes"
